@@ -6,7 +6,7 @@
 #
 # http://www.rqtl.org
 #
-# 21 March 2012
+# 26 November 2012
 ##############################################################
 
 ############################################################
@@ -148,6 +148,9 @@ summary(out.all, threshold=3, format="allpeaks")
 
 summary(out.all, threshold=3, format="allpheno")
 
+summary(out.all, threshold=3, format="tabByCol")
+summary(out.all, threshold=3, format="tabByChr")
+
 ############################################################
 # Two-dimensional, two-QTL scans
 ############################################################
