@@ -2,9 +2,9 @@
  * 
  * scanone_hk.h
  *
- * copyright (c) 2001-6, Karl W Broman
+ * copyright (c) 2001-2010, Karl W Broman
  *
- * last modified Feb, 2006
+ * last modified Jul, 2010
  * first written Nov, 2001
  *
  *     This program is free software; you can redistribute it and/or
@@ -40,7 +40,7 @@
 void R_scanone_hk(int *n_ind, int *n_pos, int *n_gen,
 		  double *genoprob, double *addcov, int *n_addcov, 
                   double *intcov, int *n_intcov, double *pheno, int *nphe,
-		  double *weights, double *result);
+		  double *weights, double *result, int *ind_noqtl);
 
 /**********************************************************************
  * 
@@ -76,11 +76,14 @@ void R_scanone_hk(int *n_ind, int *n_pos, int *n_gen,
  * Result       Result matrix of size [n_pos x (nphe)] containing the
  *              LOD scores for each phenotype
  *
+ * ind_noqtl    Indicators (0/1) of which individuals should be excluded 
+ *              from QTL effects.  
+ *
  **********************************************************************/
 
 void scanone_hk(int n_ind, int n_pos, int n_gen, double ***Genoprob,
                 double **Addcov, int n_addcov, double **Intcov, 
 		int n_intcov, double *pheno, int nphe, double *weights,
-		double **Result);
+		double **Result, int *ind_noqtl);
 
 /* end of scanone_hk.h */
